@@ -1,11 +1,13 @@
 import pandas as pd
+import numpy as np
+import ffn as f
 import matplotlib.pyplot as plt
-from StringIO import StringIO
+from io import StringIO
 import prettytable
 
-import blpapipd as bapd
+import blpapipd.blpapipd as bdu
 
-#from matplotlib.backends.backend_pdf import PdfPages
+from matplotlib.backends.backend_pdf import PdfPages
 
 from matplotlib.font_manager import FontProperties
 
@@ -108,21 +110,22 @@ def plot_voltron(vi,pdf_pages):
     pdf_pages.savefig()
         
 
-def main():
-    s=bapd.initBBGSession()
-    spx=bapd.getTimeSeries(s,'SPX Index','PX_LAST')
-    spx_ivol=bapd.getTimeSeries(s,'SPX Index','12MTH_IMPVOL_100.0%MNY_DF')
+# def main():
+#     s=bdu.initBBGSession()
+#     spx=bdu.getTimeSeries(s,'SPX Index','PX_LAST')
+#     spx_ivol=bdu.getTimeSeries(s,'SPX Index','12MTH_IMPVOL_100.0%MNY_DF')
 
-    spx2=spx
-    spx2.name='clnd'
+#     spx2=spx
+#     spx2.name='clnd'
     
-    #test drive plot_voltron
-    d = {'u_name':'SPX Index',
-         'u_df':pd.concat([spx,spx2]),
-         'ivol_name':'12 mo. i.vol',
-         'ivol_df':pd.DataFrame(spx_ivol,columns=['rgrsd'])}
-    plot_voltron(d)
+#     #test drive plot_voltron
+#     d = {'u_name':'SPX Index',
+#          'u_df':pd.concat([spx,spx2]),
+#          'ivol_name':'12 mo. i.vol',
+#          'ivol_df':pd.DataFrame(spx_ivol,columns=['rgrsd'])}
+#     print(d)
+#     plot_voltron(d, PdfPages)
                     
-if __name__ == "__main__":
+# if __name__ == "__main__":
     
-    main()
\ No newline at end of file
+#     main()
\ No newline at end of file
